News/Changelog — Momoko 0.5.0 documentation

### Navigation

- Momoko 0.5.0 documentation »
- index
- / modules
- / next
- / previous

# News/Changelog

## 0.5.0 (2012-07-30)

- Removed all Adisp related code.
- Refactored connection pool and connection polling.
- Just pass all unspecified arguments to `BlockingPool` and `AsyncPool`. So `connection_factory` can be used again.

## 0.4.0 (2011-12-15)

- Reorganized classes and files.
- Renamed `momoko.Client` to `momoko.AsyncClient`.
- Renamed `momoko.Pool` to `momoko.AsyncPool`.
- Added a client and pool for blocking connections, `momoko.BlockingClient` and `momoko.BlockingPool`.
- Added `PoolError` to the import list in `__init__.py`.
- Added an example that uses Tornado’s gen module and Swift.
- Callbacks are now optional for `AsyncClient`.
- `AsyncPool` and `Poller` now accept a ioloop argument. [fzzbt]
- Unit tests have been added. [fzzbt]

## 0.3.0 (2011-08-07)

- Renamed `momoko.Momoko` to `momoko.Client`.
- Programming in blocking-style is now possible with `AdispClient`.
- Support for Python 3 has been added.
- The batch and chain fucntion now accepts different arguments. See the documentation for details.

## 0.2.0 (2011-04-30)

- Removed `executemany` from `Momoko`, because it can not be used in asynchronous mode.
- Added a wrapper class, `Momoko`, for `Pool`, `BatchQuery` and `QueryChain`.
- Added the `QueryChain` class for executing a chain of queries (and callables) in a certain order.
- Added the `BatchQuery` class for executing batches of queries at the same time.
- Improved `Pool._clean_pool`. It threw an `IndexError` when more than one connection needed to be closed.

## 0.1.0 (2011-03-13)

- Initial release.

}